#!/bin/bash
# Script to add PPA and apps to the phone
#
# Script does the following:-
# * adds ppas
# * adds apps
#
# Assumptions:-
# * Device already running some build of Ubuntu Touch and is connected via USB
# * You're already connected to the network on the device
#
# (c) 2013 Canonical - Alan Pope alan.pope@canonical.com

UBUNTU_ROOT="/"

function adb_root {
  echo ":: Run adb root"
  adb root
  if [ $? -ne "0" ]; then
    echo ":: adb root failed"
    exit 1
  fi
}

function pause {
    echo ":: Wait $1"
    sleep $1
}

function wait_for_device {
  echo -n ":: Waiting for device to come back ."
  STATE="unknown"
  while [ "$STATE" ==  "unknown" ];
  do
    echo -n "."
    STATE=`adb get-state`
    sleep 15
  done
  echo " "
}

# Setup network on device
adb_root
pause 5

echo ":: Build script to do post-install tasks"
TMP_FILE=$(mktemp)

cat > $TMP_FILE << 'EOF'
#!/bin/bash
export PATH="/sbin:/usr/sbin:/bin:/usr/bin" 
add-apt-repository -y ppa:ubuntu-touch-coreapps-drivers/collection
add-apt-repository -y ppa:ubuntu-touch-coreapps-drivers/daily
apt-get update
apt-get install --yes touch-collection touch-coreapps
EOF

echo ":: Installing apps"
adb push $TMP_FILE $UBUNTU_ROOT/$TMP_FILE
adb shell chmod 755 $UBUNTU_ROOT/$TMP_FILE
adb shell chroot $UBUNTU_ROOT $UBUNTU_ROOT/$TMP_FILE

echo ":: Done"
