#!/bin/bash
#
# adhoc_branch_build_run.sh
#
# Script to grab any branch for a touch app, build it push it to the device
# Expects one parameter which is the branch. e.g.
#
# ./tbbr.sh lp:~rpadovani/ubuntu-calculator-app/1217876

if [ "$1" == "" ]; then
    echo "Error: Must specify a branch as a parameter"
    echo "e.g. ./tbbr.sh lp:~rpadovani/ubuntu-calculator-app/1217876"
    exit 99
fi

BRANCH=$1
BUILDDIR=$(mktemp -d)
HERE=$(pwd)

cd $BUILDDIR
echo `date` Branch $BRANCH 
bzr branch $BRANCH 2>&1 > $BUILDDIR/bzr.log
if [ "$?" == "0" ]; then
  echo `date` Branch OK
else
  echo `date` Branch FAIL
  exit 1
fi

cd `ls -F | grep /$`
echo `date` Build $BRANCH in `pwd`
debuild -uc -us 2>&1 > $BUILDDIR/build.log
if [ "$?" == "0" ]; then
  echo `date` Build OK
else
  echo `date` Build FAIL
  exit 2
fi

rm $BUILDDIR/*autopilot*.deb

adb shell mkdir $BUILDDIR

for DEB in $(ls $BUILDDIR/*.deb)
do
    echo `date` Send $DEB to device
    adb push $DEB $BUILDDIR 2>&1 > $BUILDDIR/push.log
    if [ "$?" == "0" ]; then
      echo `date` Push OK
    else
      echo `date` Push FAIL
      exit 3
    fi
done

echo `date` Install $DEB
adb shell dpkg -i $BUILDDIR/*.deb 2>&1 > $BUILDDIR/install.log

if [ "$?" == "0" ]; then
  echo `date` Install OK
else
  echo `date` Install FAIL
  exit 4
fi

cd $HERE

echo `date` Temp files in $BUILDDIR can now be deleted
