#!/bin/bash
# Script to backup phablet manually to a file. As the phablet-flash tool
# now backs up home just fine, this script backs up all the other files
# I need which don't live in the home directory
#
# Currently backs up:-
#   /var/lib/vnstat (database for vnstat tool to track data usage)
#   /home/phablet
#   /etc/NetworkManager/system-connections
#
# Assumptions:-
# * Device already running some build of Ubuntu Touch and is connected via USB
#
# (c) 2013 Canonical - Alan Pope alan.pope@canonical.com

UBUNTU_ROOT=""
BACKUP_LOCATION="$HOME/Downloads"
DATESTAMP=`date +%Y%m%d`-`date +%H%M%S`

function adb_root {
  echo ":: Run adb root"
  adb root
  if [ $? -ne "0" ]; then
    echo ":: adb root failed"
    exit 1
  fi
}

function pause {
    echo ":: Wait $1"
    sleep $1
}


adb_root

pause 5

echo ":: Obtain device type"
DEVICETYPE=`adb shell getprop ro.cm.device | sed $'s/\r//'`
echo $DEVICETYPE
echo $DATESTAMP
BACKUPFILE="$DEVICETYPE"-"$DATESTAMP"
echo "$BACKUPFILE"

echo ":: Build script to do backup"
TMP_FILE=$(mktemp)
cat > $TMP_FILE << 'EOF'
#!/bin/bash
/bin/tar zcvf /home/vnstat.tgz /var/lib/vnstat
/bin/tar zcvf /home/phablet.tgz /home/phablet
/bin/tar zxvf /home/nm.tgz /etc/NetworkManager/system-connections
EOF

echo ":: Run backup"
adb push $TMP_FILE $TMP_FILE
adb shell chmod 755 $TMP_FILE
adb shell $TMP_FILE

echo ":: Download backup to this computer"
adb pull $UBUNTU_ROOT/home/vnstat.tgz $BACKUP_LOCATION/vnstat.tgz
adb pull $UBUNTU_ROOT/home/phablet.tgz $BACKUP_LOCATION/phablet.tgz
adb pull $UBUNTU_ROOT/home/nm.tgz $BACKUP_LOCATION/nm.tgz
mv $BACKUP_LOCATION/vnstat.tgz $BACKUP_LOCATION/$BACKUPFILE-vnstat.tgz
mv $BACKUP_LOCATION/phablet.tgz $BACKUP_LOCATION/$BACKUPFILE-phablet.tgz
mv $BACKUP_LOCATION/nm.tgz $BACKUP_LOCATION/$BACKUPFILE-nm.tgz
ls -l $BACKUP_LOCATION/$BACKUPFILE-vnstat.tgz
ls -l $BACKUP_LOCATION/$BACKUPFILE-phablet.tgz
ls -l $BACKUP_LOCATION/$BACKUPFILE-nm.tgz
file $BACKUP_LOCATION/$BACKUPFILE-vnstat.tgz
file $BACKUP_LOCATION/$BACKUPFILE-phablet.tgz
file $BACKUP_LOCATION/$BACKUPFILE-nm.tgz

echo ":: Delete backup file from device"
adb shell rm -r $UBUNTU_ROOT/home/vnstat.tgz
adb shell rm -r $UBUNTU_ROOT/home/phablet.tgz
adb shell rm -r $UBUNTU_ROOT/home/nm.tgz
