#!/bin/bash
# Script to wrap phablet-flash
#
# Script does the following:-
# * Flash device (via phablet-flash)
# * Add applications from collections PPA
# * Reboot
#
# Assumptions:-
# * Device already running some build of Ubuntu Touch and is connected via USB
# * You're on Wifi and want the device to be on the same Wifi network
#
# (c) 2013 Canonical - Alan Pope alan.pope@canonical.com

UBUNTU_ROOT="/data/ubuntu"

function adb_root {
  echo ":: Run adb root"
  adb root
  if [ $? -ne "0" ]; then
    echo ":: adb root failed"
    exit 1
  fi
}

function pause {
    echo ":: Wait $1"
    sleep $1
}

function wait_for_device {
  echo -n ":: Waiting for device to come back ."
  STATE="unknown"
  while [ "$STATE" ==  "unknown" ];
  do
    echo -n "."
    STATE=`adb get-state`
    sleep 15
  done
  echo " "
}

adb_root

pause 5

echo ":: Delete old zip files to possibly regain space from /sdcard"
adb shell rm -r /sdcard/*.zip

echo ":: Flash device"
phablet-flash cdimage-touch
FLASH_RESULT=$?
if [ $FLASH_RESULT == "0" ]; then
  echo ":: Flash success"
else
  echo ":: Flash failed"
  exit 1
fi

wait_for_device
pause 10
adb_root
pause 5

echo ":: Build script to do post-install tasks"
TMP_FILE=$(mktemp)

cat > $TMP_FILE << 'EOF'
#!/bin/bash
export PATH="/sbin:/usr/sbin:/bin:/usr/bin" 
add-apt-repository -y ppa:ubuntu-touch-coreapps-drivers/collection
add-apt-repository -y ppa:ubuntu-touch-coreapps-drivers/daily
apt-get update
apt-get install --yes touch-collection touch-coreapps
perl -p -i -e 's/false/true/' /usr/share/qml-phone-shell/Dash/Apps/ApplicationsFilterGrid.qml
EOF

echo ":: Installing apps"
adb push $TMP_FILE $UBUNTU_ROOT/$TMP_FILE
adb shell chmod 755 $UBUNTU_ROOT/$TMP_FILE
adb shell chroot $UBUNTU_ROOT $UBUNTU_ROOT/$TMP_FILE

pause 10

echo ":: Reboot"
adb reboot

wait_for_device

echo ":: Delete old zip files to possibly regain space from /sdcard"
adb shell rm -r /sdcard/*.zip

echo ":: Done"



