#!/bin/bash
# Script to wrap phablet-flash and phablet-test-run
#
# Script does the following:-
# * Flash device (via phablet-flash)
# * Test apps via autopilot
#
# Assumptions:-
# * Device already running some build of Ubuntu Touch and is connected via USB
# * You're on Wifi and want the device to be on the same Wifi network
#
# Helpful if you allow phablet-network to run passwordless via sudo
# but not required. I did this by adding a line to /etc/sudoers.d/phab.conf :-
#
# alan  ALL=(ALL) NOPASSWD: /usr/bin/phablet-network
#
# (c) 2013 Canonical - Alan Pope alan.pope@canonical.com

UBUNTU_ROOT="/"
DATESTAMP=`date +%Y%m%d`-`date +%H%M%S`
TMP_DIR="$HOME/phablet-testing/$DATESTAMP"
mkdir -p $TMP_DIR

function adb_root {
  echo ":: Run adb root"
  adb root
  if [ $? -ne "0" ]; then
    echo ":: adb root failed"
    exit 1
  fi
}

function pause {
    echo ":: Wait $1"
    sleep $1
}

function wait_for_device {
  echo -n ":: Waiting for device to come back ."
  STATE="unknown"
  while [ "$STATE" ==  "unknown" ];
  do
    echo -n "."
    STATE=`adb get-state`
    sleep 15
  done
  echo " "
}

date

adb_root

pause 5

#echo ":: Delete old zip files to possibly regain space from /sdcard"
#adb shell rm -r /sdcard/*.zip

echo ":: Flash device from scratch"
#phablet-flash cdimage-touch -b --pending 
phablet-flash ubuntu-system --channel=daily-proposed
FLASH_RESULT=$?
if [ $FLASH_RESULT == "0" ]; then
  echo ":: Flash success"
else
  echo ":: Flash failed"
  exit 1
fi

wait_for_device
pause 10

echo ":: Enable developer mode"
adb shell touch /userdata/.writable_image
adb reboot
wait_for_device
pause 5

echo ":: Delete old zip files to possibly regain space from /sdcard"
adb shell rm -r /sdcard/*.zip

echo ":: Verify flashed version"

adb shell cat /var/log/installer/media-info

echo ":: Setup networking"

phablet-network -i
pause 5

echo ":: Setup test environment"

phablet-test-run -i
pause 5

echo ":: Get list of autopilot tests!"
TMP_FILE=$(mktemp)
adb shell apt-cache search app-autopilot | awk '{ print $1 }' > $TMP_FILE

echo ":: Start processing each app"
for F in $(cat $TMP_FILE) ; do
  # phablet-test-run -n -p 'qml-phone-shell-autopilot' qml_phone_shell
  AUPACKAGE=$F
  APPACKAGE=${F%%-autopilot}
  MODULE=`echo $APPACKAGE | tr \- _`
  echo ":: Starting test for $AUPACKAGE"
  mkdir -p $TMP_DIR/$MODULE
  echo phablet-test-run -o $TMP_DIR/$MODULE -p $AUPACKAGE $MODULE
  phablet-test-run -o $TMP_DIR/$MODULE -p $AUPACKAGE $MODULE 
done;

echo ":: Reboot to cleanup"
adb reboot

wait_for_device

echo ":: Done"

date



