#!/bin/bash
# Script to set a more secure password for the phablet user
#
# Script does the following:-
# * changes password for default phablet user
# * echos the password to the screen
#
# Assumptions:-
# * Device already running some build of Ubuntu Touch and is connected via USB
# * You're already connected to the network on the device
#
# (c) 2013 Canonical - Alan Pope alan.pope@canonical.com

UBUNTU_ROOT="/data/ubuntu"

function adb_root {
  echo ":: Run adb root"
  adb root
  if [ $? -ne "0" ]; then
    echo ":: adb root failed"
    exit 1
  fi
}

function pause {
    echo ":: Wait $1"
    sleep $1
}

function wait_for_device {
  echo -n ":: Waiting for device to come back ."
  STATE="unknown"
  while [ "$STATE" ==  "unknown" ];
  do
    echo -n "."
    STATE=`adb get-state`
    sleep 15
  done
  echo " "
}

# Setup network on device
adb_root
pause 5

echo ":: Build script to fix password"
TMP_FILE=$(mktemp)

cat > $TMP_FILE << 'EOF'
#!/bin/bash
export PATH="/sbin:/usr/sbin:/bin:/usr/bin" 
apt-get update
apt-get install --yes pwgen
NEWPASS=$(pwgen 8 1)
echo phablet:$NEWPASS | /usr/sbin/chpasswd
if [ $? -ne "0" ]; then
  echo ":: Changing password failed"
  exit 1
else
  echo ":: New password for phablet user is $NEWPASS"
fi
EOF

echo ":: Installing apps"
adb push $TMP_FILE $UBUNTU_ROOT/$TMP_FILE
adb shell chmod 755 $UBUNTU_ROOT/$TMP_FILE
adb shell chroot $UBUNTU_ROOT $UBUNTU_ROOT/$TMP_FILE

echo ":: Reboot device"
adb reboot

echo ":: Done"
